# Changelog
-----
All noteable changes to this project will be documented in this file. 

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

Change log adopted from the transitspectroscopy package by Nestor Espinoza. 

## [0.1.0] - 2023-05-03
### Added
- Developers: Tyler Baines and Mees Fix
- Basic setup and installation files. 
- First version of package under revision and under going testing.
- Updating code and updating data files in package. 

